import android.annotation.TargetApi;
import android.content.Context;
import android.content.res.Configuration;
import android.graphics.Color;
import android.graphics.Typeface;
import android.graphics.drawable.Drawable;
import android.os.Build;
import android.support.v4.content.ContextCompat;
import android.support.v4.view.PagerAdapter;
import android.text.Html;
import android.view.Gravity;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ImageView;
import android.widget.RelativeLayout;
import android.widget.TextView;

import com.eyeexamtest.eyecareplus.R;
import com.eyeexamtest.eyecareplus.apiservice.AppItem;
import com.eyeexamtest.eyecareplus.apiservice.Disease;
import com.eyeexamtest.eyecareplus.apiservice.PatientConditions;
import com.eyeexamtest.eyecareplus.apiservice.PatientService;
import com.eyeexamtest.eyecareplus.component.ViewPagerFixed;
import com.eyeexamtest.eyecareplus.utils.ResourceService;
import com.eyeexamtest.eyecareplus.utils.TypeFaceService;

import java.util.List;

/**
 * Created by tsimonya on 5/6/2015.
 */
public class HintsPagerAdapter extends PagerAdapter {
    private Context context;
    private int hintCount, hintCounts;
    private final String[] texts;
    private final Drawable[] images;
    private final Typeface rLight;
    private boolean checkLang = false;

    public HintsPagerAdapter(Context context, AppItem appItem, boolean isLazyEye) {
        this.context = context;
        ResourceService rs = ResourceService.getInstance();
        TypeFaceService tfs = TypeFaceService.getInstance();

        rLight = tfs.getRobotoLight();
        PatientConditions conditions = PatientService.getInstance().getPatientConditions();
        List<Disease> diseases = conditions.getDiseases();
        hintCounts = rs.getInt(appItem, "hints");
        List<AppItem> purchasedAppItems = PatientService.getInstance().getPurchasedWorkoutPlans();
        if (appItem.getType() == AppItem.Type.TRAINING) {
            if ((diseases.contains(Disease.LAZY_EYE) || purchasedAppItems.contains(AppItem.LAZY_EYE_WORKOUT) || isLazyEye)) {
                hintCount = hintCounts;
            } else {
                hintCount = hintCounts - 1;
            }
        } else {
            hintCount = hintCounts;
        }
        texts = new String[hintCount];
        images = new Drawable[hintCount];
        for (int i = 0; i < hintCount; i++) {
            String hintKey = "hint_" + i;
            texts[i] = rs.getString(appItem, hintKey);
            String imgKey = rs.getString(appItem, hintKey + "_icon");
            images[i] = imgKey.endsWith("_draw") ? rs.getDrawable(imgKey) : rs.getSVG(imgKey);
        }
    }

    @Override
    public boolean isViewFromObject(View view, Object object) {
        return view == ((RelativeLayout) object);
    }

    @Override
    public int getCount() {
        return hintCount;
    }

    public static boolean isTablet(Context context) {
        return (context.getResources().getConfiguration().screenLayout & Configuration.SCREENLAYOUT_SIZE_MASK) >= Configuration.SCREENLAYOUT_SIZE_LARGE;
    }

    @TargetApi(Build.VERSION_CODES.JELLY_BEAN_MR1)
    @Override
    public Object instantiateItem(final ViewGroup container, int position) {
        int topMargin = context.getResources().getDimensionPixelSize(
                R.dimen.hint_text_margin_top);
        int hintPageTextMargin = context.getResources().getDimensionPixelSize(R.dimen.hint_page_text_margin);
        RelativeLayout layout = new RelativeLayout(context);
        layout.setBackgroundColor(Color.WHITE);
        int size = context.getResources().getDimensionPixelSize(
                R.dimen.hint_icon_size);
        RelativeLayout.LayoutParams imageviewParams = new RelativeLayout.LayoutParams(
                size, size);
        RelativeLayout.LayoutParams bottomTextParams = new RelativeLayout.LayoutParams(
                RelativeLayout.LayoutParams.WRAP_CONTENT,
                RelativeLayout.LayoutParams.WRAP_CONTENT);
        imageviewParams.addRule(RelativeLayout.ALIGN_PARENT_TOP);
        imageviewParams.addRule(RelativeLayout.CENTER_IN_PARENT);
        ImageView imageView = new ImageView(context);
        imageView.setLayoutParams(imageviewParams);
        imageView.setLayerType(View.LAYER_TYPE_SOFTWARE, null);
        imageView.setImageDrawable(images[position]);
        bottomTextParams.setMargins(100, 0, 100, topMargin);

        TextView txtDown = new TextView(context);
        txtDown.setTextColor(ContextCompat.getColor(context, R.color.darkblue));
        txtDown.setText(Html.fromHtml(texts[position]));
        txtDown.setTextSize(context.getResources().getDimension(R.dimen.result_text_size_training) / context.getResources().getDisplayMetrics().density);
        txtDown.setTypeface(rLight);
        txtDown.setGravity(Gravity.CENTER);
        bottomTextParams.addRule(RelativeLayout.ALIGN_PARENT_BOTTOM);
        bottomTextParams.addRule(RelativeLayout.CENTER_HORIZONTAL);
        txtDown.setLayoutParams(bottomTextParams);
        txtDown.bringToFront();
        layout.addView(txtDown);
        layout.addView(imageView);
        ((ViewPagerFixed) container).addView(layout, 0);
        return layout;
    }

    @Override
    public void destroyItem(ViewGroup container, int position, Object object) {
        ((ViewPagerFixed) container).removeView((RelativeLayout) object);
    }
}